==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/dataprotect/api/gwt/js/JsGenerationContent.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */

package net.bluemind.dataprotect.api.gwt.js;

import com.google.gwt.core.client.JavaScriptObject;

public class JsGenerationContent extends JavaScriptObject {

	protected JsGenerationContent() {}

	public final native int getGenerationId()
	/*-{
	return this["generationId"];
	}-*/;

	public final native void setGenerationId(int generationId)
	/*-{
       this["generationId"] = generationId;
	}-*/;

	public final native com.google.gwt.core.client.JsArray<net.bluemind.core.container.model.gwt.js.JsItemValue<net.bluemind.domain.api.gwt.js.JsDomain>> getDomains()
	/*-{
	return this["domains"];
	}-*/;

	public final native void setDomains(com.google.gwt.core.client.JsArray<net.bluemind.core.container.model.gwt.js.JsItemValue<net.bluemind.domain.api.gwt.js.JsDomain>> domains)
	/*-{
       this["domains"] = domains;
	}-*/;

	public final native com.google.gwt.core.client.JsArray<net.bluemind.core.container.model.gwt.js.JsItemValue<net.bluemind.directory.api.gwt.js.JsDirEntry>> getEntries()
	/*-{
	return this["entries"];
	}-*/;

	public final native void setEntries(com.google.gwt.core.client.JsArray<net.bluemind.core.container.model.gwt.js.JsItemValue<net.bluemind.directory.api.gwt.js.JsDirEntry>> entries)
	/*-{
       this["entries"] = entries;
	}-*/;

	public final native com.google.gwt.core.client.JsArray<net.bluemind.dataprotect.api.gwt.js.JsRestoreOperation> getCapabilities()
	/*-{
	return this["capabilities"];
	}-*/;

	public final native void setCapabilities(com.google.gwt.core.client.JsArray<net.bluemind.dataprotect.api.gwt.js.JsRestoreOperation> capabilities)
	/*-{
       this["capabilities"] = capabilities;
	}-*/;

	public static native  JsGenerationContent create()
	/*-{
       var ret = {};
       return ret;
	}-*/;

}

==> net.bluemind.p2.platform-5.4.2760.zip: net/bluemind/dataprotect/api/gwt/js/JsGenerationContent.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */

package net.bluemind.dataprotect.api.gwt.js;

import com.google.gwt.core.client.JavaScriptObject;

public class JsGenerationContent extends JavaScriptObject {

	protected JsGenerationContent() {}

	public final native int getGenerationId()
	/*-{
	return this["generationId"];
	}-*/;

	public final native void setGenerationId(int generationId)
	/*-{
       this["generationId"] = generationId;
	}-*/;

	public final native com.google.gwt.core.client.JsArray<net.bluemind.core.container.model.gwt.js.JsItemValue<net.bluemind.domain.api.gwt.js.JsDomain>> getDomains()
	/*-{
	return this["domains"];
	}-*/;

	public final native void setDomains(com.google.gwt.core.client.JsArray<net.bluemind.core.container.model.gwt.js.JsItemValue<net.bluemind.domain.api.gwt.js.JsDomain>> domains)
	/*-{
       this["domains"] = domains;
	}-*/;

	public final native com.google.gwt.core.client.JsArray<net.bluemind.dataprotect.api.gwt.js.JsRestoreOperation> getCapabilities()
	/*-{
	return this["capabilities"];
	}-*/;

	public final native void setCapabilities(com.google.gwt.core.client.JsArray<net.bluemind.dataprotect.api.gwt.js.JsRestoreOperation> capabilities)
	/*-{
       this["capabilities"] = capabilities;
	}-*/;

	public final native com.google.gwt.core.client.JsArray<net.bluemind.dataprotect.api.gwt.js.JsGenerationIndex> getEntries()
	/*-{
	return this["entries"];
	}-*/;

	public final native void setEntries(com.google.gwt.core.client.JsArray<net.bluemind.dataprotect.api.gwt.js.JsGenerationIndex> entries)
	/*-{
       this["entries"] = entries;
	}-*/;

	public static native  JsGenerationContent create()
	/*-{
       var ret = {};
       return ret;
	}-*/;

}
